==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fCheckcast.h <==
// class soot.coffi.Instruction_Checkcast

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 6ae0460cd786ea18 soot_coffi_Instruction__5fCheckcast
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fCheckcast_H_
#define _JC_soot_coffi_Instruction__5fCheckcast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$sub_refs	_jc_soot_coffi_Instruction__5fCheckcast$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs	_jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$refs	_jc_soot_coffi_Instruction__5fCheckcast$refs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$nonrefs	_jc_soot_coffi_Instruction__5fCheckcast$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$object	_jc_soot_coffi_Instruction__5fCheckcast$object;

typedef const struct _jc_soot_coffi_Instruction__5fCheckcast$vmethods	_jc_soot_coffi_Instruction__5fCheckcast$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fCheckcast$vtable	_jc_soot_coffi_Instruction__5fCheckcast$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fCheckcast$vtype	_jc_soot_coffi_Instruction__5fCheckcast$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fCheckcast$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fCheckcast$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fCheckcast$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fCheckcast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fCheckcast$vmethods	soot_coffi_Instruction__5fCheckcast;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fCheckcast$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fCheckcast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fCheckcast$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fCheckcast$refs {
    _jc_soot_coffi_Instruction__5fCheckcast$sub_refs	soot_coffi_Instruction__5fCheckcast;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fCheckcast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs	soot_coffi_Instruction__5fCheckcast;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fCheckcast$object {
	_jc_soot_coffi_Instruction__5fCheckcast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fCheckcast$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fCheckcast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fCheckcast$vtype _jc_soot_coffi_Instruction__5fCheckcast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fCheckcast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fCheckcast$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fCheckcast_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fCheckcast.h <==
// class soot.coffi.Instruction_Checkcast

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class 6ae0460cd786ea18 soot_coffi_Instruction__5fCheckcast
// @dep_class d13384827121be19 soot_coffi_Instruction__5fintindex

// header file dependencies
// @dep_header soot_coffi_Instruction__5fintindex

#include "soot/coffi/Instruction__5fintindex.h"

#ifndef _JC_soot_coffi_Instruction__5fCheckcast_H_
#define _JC_soot_coffi_Instruction__5fCheckcast_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$sub_refs	_jc_soot_coffi_Instruction__5fCheckcast$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs	_jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$refs	_jc_soot_coffi_Instruction__5fCheckcast$refs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$nonrefs	_jc_soot_coffi_Instruction__5fCheckcast$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fCheckcast$object	_jc_soot_coffi_Instruction__5fCheckcast$object;

typedef const struct _jc_soot_coffi_Instruction__5fCheckcast$vmethods	_jc_soot_coffi_Instruction__5fCheckcast$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fCheckcast$vtable	_jc_soot_coffi_Instruction__5fCheckcast$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fCheckcast$vtype	_jc_soot_coffi_Instruction__5fCheckcast$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fCheckcast$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fCheckcast$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fCheckcast$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fCheckcast$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fintindex$vmethods	soot_coffi_Instruction__5fintindex;
	_jc_soot_coffi_Instruction__5fCheckcast$vmethods	soot_coffi_Instruction__5fCheckcast;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fCheckcast$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fCheckcast$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fCheckcast$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fCheckcast$refs {
    _jc_soot_coffi_Instruction__5fCheckcast$sub_refs	soot_coffi_Instruction__5fCheckcast;
    _jc_soot_coffi_Instruction__5fintindex$sub_refs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fCheckcast$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fintindex$sub_nonrefs	soot_coffi_Instruction__5fintindex;
    _jc_soot_coffi_Instruction__5fCheckcast$sub_nonrefs	soot_coffi_Instruction__5fCheckcast;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fCheckcast$object {
	_jc_soot_coffi_Instruction__5fCheckcast$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fCheckcast$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fCheckcast$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fCheckcast$vtype _jc_soot_coffi_Instruction__5fCheckcast$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fCheckcast, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fCheckcast$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fCheckcast_H_ */
